%-----------------------------------------------------------------------------%
% Copyright (C) 1997-1998, 2001, 2006 The University of Melbourne.
% Copyright (C) 2018, 2022 The Mercury team.
% This file is distributed under the terms specified in COPYING.LIB.
%-----------------------------------------------------------------------------%

:- module complex_numbers.
:- interface.

:- include_module complex.
:- include_module complex_float.
:- include_module complex_imag.
:- include_module float_complex.
:- include_module float_imag.
:- include_module imag.
:- include_module imag_complex.
:- include_module imag_float.

%-----------------------------------------------------------------------------%
:- end_module complex_numbers.
%-----------------------------------------------------------------------------%
